#
# spec file for package jeromq
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jeromq
Version:        0.5.3
Release:        1.1
Summary:        Pure Java implementation of libzmq
License:        MPL-2.0+
Group:          Development/Libraries/Java
URL:            https://github.com/zeromq/jeromq
Source0:        https://github.com/zeromq/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(eu.neilalexander:jnacl)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch

%description
Pure Java implementation of libzmq.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :nexus-staging-maven-plugin

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md CHANGELOG.md AUTHORS
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Fri Feb 21 2025 ming li <mli@suse.com>
- Update to version 0.5.3:
  * Add peer support disconnect
  * Fix issue where socket identity was failing with overflow when
    identity was bigger than 127
  * Make JeroMQ compatiable with Android API Level 19
  * Add tests and build on Java 17. Helping dependecies resolution
    by activating more profiles and don't try to publish on forks
  * ZMQ_HEARTBEAT is not useful without sending an hello message.
    To solve that, the majordomo worker still has to implement heartbeat.
    With this new option, whenever the connection drops and reconnects
    the hello message will be sent, greatly simplify the majordomo protocol,
    as now READY and HEARTBEAT can be handled by zeromq.
  * Jeromq is not thread-safe, so port CLIENT and SERVER sockets from libzmq,
    which are thread-safe sockets.
  * Add Client/Server support to ZFrame.
  * Radio-Dish implementation.
  * Port of https://github.com/zeromq/libzmq/pull/3871, router can handle peer
    disconnected.
  * Adding critical and notification exceptions handlers in zmq.poll.Poller.
  * Many improvement to error handling, with more error messages.
  * Fix ZMQ_REQ_CORRELATE.
  * A new ZBeacon implementation.
  * IPC protocol now comply to java.net.preferIPv4Stack or java.net.preferIPv6Addresses
    for the choice of the TCP stack to use.
  * Improved monitor, with added events in some mechanisms.
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Wed Jun 15 2022 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jeromq 0.5.2
